@@ -9,11 +9,9 @@ import pdfstream.integration.main as integ
     "bg_img_key,kwargs",
     [
         (None, {}),
-        ('Kapton_img', {}),
         ('Kapton_img', {'bg_scale': 0.001}),
-        ('Kapton_img', {'bg_scale': 0.001, 'mask_setting': "OFF"}),
-        ('Kapton_img', {'bg_scale': 0.001, 'mask_setting': {"alpha": 3}}),
-        ('Kapton_img', {'bg_scale': 0.001, 'integ_setting': {'npt': 1024}}),
+        ('Kapton_img', {'mask_setting': {"alpha": 3}}),
+        ('Kapton_img', {'integ_setting': {'npt': 1024}}),
     ]
 )
 def test_get_chi(db, bg_img_key, kwargs):
