@@ -2,8 +2,9 @@ from pprint import pprint
 
 import pytest
 from mongomock import MongoClient
+from pyobjcryst.crystal import Crystal
 
-import pdfstream.parsers as ctd
+from pdfstream.parsers.ciffile import cif_to_dict, to_crystal
 
 
 @pytest.mark.parametrize(
@@ -16,7 +17,7 @@ import pdfstream.parsers as ctd
 def test_cif_to_dict(db, kwargs):
     client = MongoClient()
     coll = client.db.coll
-    dcts = ctd.cif_to_dict(
+    dcts = cif_to_dict(
         db["Ni_stru_file"],
         **kwargs
     )
@@ -24,3 +25,8 @@ def test_cif_to_dict(db, kwargs):
         pprint(dct)
         # test mongo friendly
         coll.insert_one(dct)
+
+
+def test_to_crystal(doc2):
+    real = to_crystal(doc2)
+    assert isinstance(real, Crystal)
